@@ -1,8 +1,8 @@
+( cd usr/lib ; rm -rf libtag.so )
+( cd usr/lib ; ln -sf libtag.so.1 libtag.so )
+( cd usr/lib ; rm -rf libtag_c.so )
+( cd usr/lib ; ln -sf libtag_c.so.0 libtag_c.so )
 ( cd usr/lib ; rm -rf libtag.so.1 )
-( cd usr/lib ; ln -sf libtag.so.1.9.0 libtag.so.1 )
+( cd usr/lib ; ln -sf libtag.so.1.7.2 libtag.so.1 )
 ( cd usr/lib ; rm -rf libtag_c.so.0 )
 ( cd usr/lib ; ln -sf libtag_c.so.0.0.0 libtag_c.so.0 )
-( cd usr/lib ; rm -rf libtag_c.so )
-( cd usr/lib ; ln -sf libtag_c.so.0.0.0 libtag_c.so )
-( cd usr/lib ; rm -rf libtag.so )
-( cd usr/lib ; ln -sf libtag.so.1.9.0 libtag.so )
